==> freediams_0.4.2.orig.tar.gz: freediams-0.4.2/global_resources/translations/fdmainwindowplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>MainWin</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="43"/>
        <source>Can not configure MedinTux</source>
        <translation>Kann MedinTux nicht configurieren</translation>
    </message>
</context>
<context>
    <name>MainWin::Internal::MainWinPrivate</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="122"/>
        <source>Reading exchange file...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWin::Internal::MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="56"/>
        <source>DOB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="20"/>
        <source>Patient Firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="30"/>
        <source>Surname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="42"/>
        <source>Patient information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="69"/>
        <source>yyyy/MM/dd</source>
        <comment>Format de date</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="76"/>
        <source>Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="97"/>
        <source>Kg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="102"/>
        <source>lbs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="110"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="131"/>
        <source>cm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="136"/>
        <source>m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="141"/>
        <source>inches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="149"/>
        <source>Gender</source>
        <translation>Geschlecht</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="162"/>
        <source>M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="167"/>
        <source>F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="172"/>
        <source>H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="184"/>
        <source>Creatinine clearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="205"/>
        <source>mL/min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="210"/>
        <source>mL/sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="218"/>
        <source>Creatinine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="239"/>
        <source>mg/L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="244"/>
        <source>mg/dL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="249"/>
        <source>mmol/L</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="254"/>
        <source>µmol/L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="266"/>
        <source>List of medications allergies</source>
        <translation>Liste der unverträglichen Medikamente</translation>
    </message>
</context>
<context>
    <name>MainWin::MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="175"/>
        <source>Creating Main Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="234"/>
        <source>Transmitting posologies...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="260"/>
        <source>Initializing drugs database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="266"/>
        <source>Entering selection mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="494"/>
        <source>Save actual prescription ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="495"/>
        <source>The actual prescription is not empty. Do you want to save it before creating a new one ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="601"/>
        <source>Opening a prescription : merge or replace ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="602"/>
        <source>There is a prescription inside editor, do you to replace it or to add the opened prescription ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="603"/>
        <source>Replace prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="603"/>
        <source>Add to prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="604"/>
        <source>Open a prescription</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="155"/>
        <source>Preparing dosage transmission</source>
        <translation>Bereite Dosis Transmission vor</translation>
    </message>
</context>
<context>
    <name>diMedinTux</name>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="66"/>
        <source>Automatic configuration for MedinTux usage</source>
        <translation>Automatische konfiguration für MedinTux</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="67"/>
        <source>This assistant will create a new entrie into the users&apos; menu of DrTux.
You can create a new prescription by clicking this menu.
Please take care that if DrTux&apos; location changes, or if FreeDiams&apos; location changes, you must reconfigure DrTux with this assitant.</source>
        <translation>Der Assistent wird ein neuen Eintrag im Anwendermenü von DrTux anlegen.
Sie können ein neues Rezept durch anklicken des Menüs erstellen.
Bitte achten sie auf die lokalen Änderungen von DrTux oder FreeDiams.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="72"/>
        <source>This assistant will try to find your MedinTux path. If it doesn&apos;t, you will be asked about this place. Then it will configure a new user&apos;s menu for DrTux and create a new list in your prescription&apos;s default list.
Please refer to the documentation.</source>
        <translation>Der assistent wird versuchen MedinTux zu finden. Wenn er nichts findet werden sie gefragt werden.Dann werden anpassungen in DrTux gemacht.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="87"/>
        <source>Please select Manager&apos;s binary path</source>
        <translation>Bitte wählen sie den Managers Pfad</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="98"/>
        <source>Unable to configure MedinTux : Resources path does not exists. Path to DrTux binary : %1</source>
        <translation>Kann MedinTux nicht konfigurieren Resources Pfad existiert nicht. Pfad zu DrTux binary %1</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="102"/>
        <source>Unable to configure MedinTux : Menus path does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation>Kann MedinTux nicht konfigurieren. Menüpfad existiert nicht und kann nichr angelegt werden. Pfad zu Dr.Tux binary %1</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="113"/>
        <source>Can not deleted old DrugsInteractions menu entry %1</source>
        <translation>Kann nicht alten DrugsInteraktions Menüeintrag löschen %1</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="119"/>
        <source>Unable to configure MedinTux : DrugsInteractions menu does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation>Kann MedinTux nicht konfigurieren.DrugsInteractions Menü existiert nicht und kann necht angelegt werden. Pfad zu DrTux binary %1</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="195"/>
        <source>DrTux is now fully configured for %1.</source>
        <translation>DrTux ist nun voll konfiguriert für %1.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="196"/>
        <source>You can run %1 using DrTux User&apos;s Menu.</source>
        <translation>Sie können %1 mit DrTux User&apos;s Menü benutzen.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="197"/>
        <source>If you encounter difficulties with DrTux integration, please refer to documentation of both applications.
%1</source>
        <translation>Wenn Schwierigkeiten bei der Dr Tux Intergration auftauchen, lesen sie die Bedienungsanleitung beider Applikationen
%1</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="199"/>
        <source>DrTux is not correctly configured.</source>
        <translation>Dr Tux ist nicht korrekt konfiguriert.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="200"/>
        <source>This assitant encountered errors during its process.</source>
        <translation>Der Assistent hatte Probleme während seines Prozesses.</translation>
    </message>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="201"/>
        <source>This is the log of the processes 
%1</source>
        <translation>Dies ist der Log der Prozesse
%1</translation>
    </message>
</context>
<context>
    <name>diMedintux</name>
    <message>
        <location filename="../../_protected/freediams/medintux_pro.cpp" line="25"/>
        <source>Prescribe with FreeDiams</source>
        <translation>Verschreiben mit FreeDiams</translation>
    </message>
</context>
</TS>

==> freediams_0.5.4.orig.tar.gz: freediams-0.5.4/global_resources/translations/fdmainwindowplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>MainWin::Internal::MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="115"/>
        <source>DOB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="107"/>
        <source>Patient information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="128"/>
        <source>yyyy/MM/dd</source>
        <comment>Format de date</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="135"/>
        <source>Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="156"/>
        <source>Kg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="161"/>
        <source>lbs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="190"/>
        <source>cm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="195"/>
        <source>m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="200"/>
        <source>inches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="208"/>
        <source>Gender</source>
        <translation>Geschlecht</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="169"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="20"/>
        <source>Patient Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="27"/>
        <source>Family or occidental last names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="34"/>
        <source>Firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="41"/>
        <source>Given names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="222"/>
        <source>Creatinine clearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="243"/>
        <source>mL/min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="248"/>
        <source>mL/sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="256"/>
        <source>Creatinine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="277"/>
        <source>mg/L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="282"/>
        <source>mg/dL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="287"/>
        <source>mmol/L</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="292"/>
        <source>µmol/L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="304"/>
        <source>Drugs precautions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWin::MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="234"/>
        <source>Creating Main Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="331"/>
        <source>Transmitting posologies...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="356"/>
        <source>Connected to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="371"/>
        <source>Initializing drugs database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="377"/>
        <source>Entering selection mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="386"/>
        <source>Reading exchange file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="718"/>
        <source>Save actual prescription ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="719"/>
        <source>The actual prescription is not empty. Do you want to save it before creating a new one ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="821"/>
        <source>Opening a prescription : merge or replace ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="822"/>
        <source>There is a prescription inside editor, do you to replace it or to add the opened prescription ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="823"/>
        <source>Replace prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="823"/>
        <source>Add to prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="824"/>
        <source>Open a prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="865"/>
        <source>Toggle patient&apos;s precautions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="213"/>
        <source>Preparing dosage transmission</source>
        <translation>Bereite Dosis Transmission vor</translation>
    </message>
</context>
<context>
    <name>diMedinTux</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="91"/>
        <source>Automatic configuration for MedinTux usage</source>
        <translation>Automatische konfiguration für MedinTux</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="92"/>
        <source>This assistant will create a new entrie into the users&apos; menu of DrTux.
You can create a new prescription by clicking this menu.
Please take care that if DrTux&apos; location changes, or if FreeDiams&apos; location changes, you must reconfigure DrTux with this assitant.</source>
        <translation>Der Assistent wird ein neuen Eintrag im Anwendermenü von DrTux anlegen.
Sie können ein neues Rezept durch anklicken des Menüs erstellen.
Bitte achten sie auf die lokalen Änderungen von DrTux oder FreeDiams.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="97"/>
        <source>This assistant will try to find your MedinTux path. If it doesn&apos;t, you will be asked about this place. Then it will configure a new user&apos;s menu for DrTux and create a new list in your prescription&apos;s default list.
Please refer to the documentation.</source>
        <translation>Der assistent wird versuchen MedinTux zu finden. Wenn er nichts findet werden sie gefragt werden.Dann werden anpassungen in DrTux gemacht.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="112"/>
        <source>Please select Manager&apos;s binary path</source>
        <translation>Bitte wählen sie den Managers Pfad</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="123"/>
        <source>Unable to configure MedinTux : Resources path does not exists. Path to DrTux binary : %1</source>
        <translation>Kann MedinTux nicht konfigurieren Resources Pfad existiert nicht. Pfad zu DrTux binary %1</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="128"/>
        <source>Unable to configure MedinTux : Menus path does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation>Kann MedinTux nicht konfigurieren. Menüpfad existiert nicht und kann nichr angelegt werden. Pfad zu Dr.Tux binary %1</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="140"/>
        <source>Can not deleted old DrugsInteractions menu entry %1</source>
        <translation>Kann nicht alten DrugsInteraktions Menüeintrag löschen %1</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="147"/>
        <source>Unable to configure MedinTux : DrugsInteractions menu does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation>Kann MedinTux nicht konfigurieren.DrugsInteractions Menü existiert nicht und kann necht angelegt werden. Pfad zu DrTux binary %1</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="224"/>
        <source>DrTux is now fully configured for %1.</source>
        <translation>DrTux ist nun voll konfiguriert für %1.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="225"/>
        <source>You can run %1 using DrTux User&apos;s Menu.</source>
        <translation>Sie können %1 mit DrTux User&apos;s Menü benutzen.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="226"/>
        <source>If you encounter difficulties with DrTux integration, please refer to documentation of both applications.
%1</source>
        <translation>Wenn Schwierigkeiten bei der Dr Tux Intergration auftauchen, lesen sie die Bedienungsanleitung beider Applikationen
%1</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="228"/>
        <source>DrTux is not correctly configured.</source>
        <translation>Dr Tux ist nicht korrekt konfiguriert.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="229"/>
        <source>This assitant encountered errors during its process.</source>
        <translation>Der Assistent hatte Probleme während seines Prozesses.</translation>
    </message>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="230"/>
        <source>This is the log of the processes 
%1</source>
        <translation>Dies ist der Log der Prozesse
%1</translation>
    </message>
</context>
<context>
    <name>diMedintux</name>
    <message>
        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="50"/>
        <source>Prescribe with FreeDiams</source>
        <translation>Verschreiben mit FreeDiams</translation>
    </message>
</context>
</TS>
